local addon, umData = ...
local function GetBuildInfo()
	local _ret = ""

	_ret = "UpgradeMe Version: "..tostring(UpgradeMe.AddonData.toc.Version).."\n\n"
	_ret = _ret.."The following builds have been updated: \n\n"
	_ret = _ret.."     Cleric\n"
	_ret = _ret.."          61SENT/10WARD/5PUR - Heals (3/3/2013)\n\n"
	_ret = _ret.."If you used any of these builds in your current weight sets please go to the weight sets tab "
	_ret = _ret.."and update your sets accordingly.  To update a set, just select the outfit you want to update, "
	_ret = _ret.."then select the weight set from the dropdown list, and finally click save outfit.\n\n"
	_ret = _ret.."If you have any questions or concerns, please let me know as I value your feedback.\n\n"
	_ret = _ret.."Thank you for using the addon,\n\n"
	_ret = _ret.."--Gralli@Faeblight"

	return _ret
end

local ChangeBackgroundColor = function(_object, _color, _alpha)
	if _color == "trash" then
		_object:SetBackgroundColor(.639, .639, .639, _alpha)
	elseif _color == "common" then
		_object:SetBackgroundColor(1, 1, 1, _alpha)
	elseif _color == "uncommon" then
		_object:SetBackgroundColor(0, .8, 0, _alpha)
	elseif _color == "rare" then
		_object:SetBackgroundColor(.149, .506, .996, _alpha)
	elseif _color == "epic" then
		_object:SetBackgroundColor(.690, .286, 1, _alpha)
	elseif _color == "relic" then
		_object:SetBackgroundColor(1, .6, 0, _alpha)
	elseif _color == "quest" then
		_object:SetBackgroundColor(1, .965, 0, _alpha)
	else
		_object:SetBackgroundColor(0, 0, 0, _alpha)
	end
end

local function LoadOutfitDefaults(_self)
	if umData.um_UI.SystemLocked then return end
	local _detail = nil
	local _ok = nil
	if umData.um_UI.HandMainID ~= "" then
		_detail = UpgradeMe.GetItemDetail(umData.um_UI.HandMainID)
		if _detail then 
			if _detail.rarity then ChangeBackgroundColor(_self.Settings.OutfitHandMainFrame, _detail.rarity, 1) end
			_self.Settings.OutfitHandMain:SetTexture("Rift", _detail.icon)
			_self.Settings.OutfitHandMainText:SetText(_detail.name)	
			_self.Settings.OutfitHandMain:SetVisible(true)
		end
	else
		ChangeBackgroundColor(_self.Settings.OutfitHandMainFrame, "black", 1)
		_self.Settings.OutfitHandMain:SetVisible(false)
		_self.Settings.OutfitHandMainText:SetText("No Main Hand Saved")		
	end
	
	if umData.um_UI.HandOffID ~= "" then
		_detail = UpgradeMe.GetItemDetail(umData.um_UI.HandOffID)
		if _detail then
			if _detail.rarity then ChangeBackgroundColor(_self.Settings.OutfitHandOffFrame, _detail.rarity, 1) end
			_self.Settings.OutfitHandOff:SetTexture("Rift", _detail.icon)
			_self.Settings.OutfitHandOffText:SetText(_detail.name)
			_self.Settings.OutfitHandOff:SetVisible(true)
		end
	else
		ChangeBackgroundColor(_self.Settings.OutfitHandOffFrame, "black", 1)	
		_self.Settings.OutfitHandOff:SetVisible(false)
		_self.Settings.OutfitHandOffText:SetText("No Off Hand Saved")	
	end
end

local function BuildConfig(self)
	local iRow = 0
	local iCol = 0
	local pFld = ""
	local lOutfits = {}

	self:SetVisible(false)
	self:SetCloseButtonVisible(true)
	self:SetTitle("UpgradeMe - Config")
	self:SetWidth(600)
	self:SetHeight(700)
	self:SetPoint("TOPCENTER", UIParent, "TOPCENTER")
	self.StatNames = {}
	self.StatWeights1 = {}
	self.StatSlider1 = {}

	self.um_TabView = UI.CreateFrame("SimpleTabView", "um_TabView", self)
	self.um_TabView:SetTabPosition("top")
	--self.um_TabView.Event.TabSelect = function(view, index) um_TabViewChanged(index) end
	self.um_TabView:SetPoint("TOPLEFT", self:GetContent(), "TOPLEFT", 0, 0)
	self.um_TabView:SetPoint("BOTTOMRIGHT", self:GetContent(), "BOTTOMRIGHT", 0, 0)

	self.um_Tab1 = UI.CreateFrame("Frame", "um_Tab1", self.um_TabView)
	self.um_Tab2 = UI.CreateFrame("Frame", "um_Tab2", self.um_TabView)
	--self.um_Tab3 = UI.CreateFrame("Frame", "um_Tab3", self.um_TabView)

	self.um_TabView:AddTab("Settings", self.um_Tab1)
	self.um_TabView:AddTab("Weight Sets", self.um_Tab2)
	--self.um_TabView:AddTab("Options", self.um_Tab3)

	--[[
	Info Config Set up Begin
	]]--
	self.Settings = {}
	self.Settings.LockUI = UI.CreateFrame("RiftCheckbox", "Settings.LockUICB", self.um_Tab1)
	self.Settings.LockUI.HelpText = "Unlock detached tooltip frame and UpgradeMe minimap button - Simply hold down right button and drag to move.\n\n\nWhen unlocked, use your scroll wheel to scale the UpgradeMe minimap button.\n\n\nYou may double click the minimap button to bring up this config panel."	
	self.Settings.LockUI:EventAttach(Event.UI.Input.Mouse.Cursor.In, function(_self) self.Settings:DisplayTip(_self, true) end, "UpgradeMe.LockUI.MouseIn")
	self.Settings.LockUI:EventAttach(Event.UI.Input.Mouse.Cursor.Out, function() self.Settings:DisplayTip(false) end, "UpgradeMe.LockUI.MouseOut")	
	self.Settings.LockUI:EventAttach(Event.UI.Checkbox.Change, function(_self) _self:LockUICBChange() end , "Settings.LockUICBChange")
	self.Settings.LockUI:SetPoint("TOPLEFT", self.um_Tab1, "TOPLEFT", 10, 10)
	self.Settings.LockUI.LockUICBChange = 
		function(_self)	
			umData.um_UI.Locked = _self:GetChecked() 
			UpgradeMe:SetUI()
		end
	self.Settings.LockUI:SetChecked(umData.um_UI.Locked)		
	self.Settings.LockUIText = UI.CreateFrame("Text", "Settings.LockUIText", self.um_Tab1)
	self.Settings.LockUIText:SetText("Lock UI")
	self.Settings.LockUIText:SetPoint("TOPLEFT", self.Settings.LockUI, "TOPRIGHT", 0, -1)

	self.Settings.UseDocker = UI.CreateFrame("RiftCheckbox", "Settings.UseDockerCB", self.um_Tab1)
	self.Settings.UseDocker.HelpText = "If enabled, the UpgradeMe minimap button will be placed inside the Dockker addon.  Requires /reloadui"
	self.Settings.UseDocker:EventAttach(Event.UI.Input.Mouse.Cursor.In, function(_self) self.Settings:DisplayTip(_self, true) end, "UpgradeMe.UseDocker.MouseIn")
	self.Settings.UseDocker:EventAttach(Event.UI.Input.Mouse.Cursor.Out, function() self.Settings:DisplayTip(false) end, "UpgradeMe.UseDocker.MouseOut")	
	self.Settings.UseDocker:EventAttach(Event.UI.Checkbox.Change, function(_self) _self:UseDockerCBChange() end , "Settings.UseDockerCBChange")
	self.Settings.UseDocker:SetPoint("TOPLEFT", self.Settings.LockUI, "BOTTOMLEFT", 0, 5)
	self.Settings.UseDocker.UseDockerCBChange = 
		function(_self)	
			umData.um_UI.UseDocker = _self:GetChecked() 
		end
	self.Settings.UseDocker:SetChecked(umData.um_UI.UseDocker)		
	self.Settings.UseDockerText = UI.CreateFrame("Text", "Settings.UseDockerText", self.um_Tab1)
	self.Settings.UseDockerText:SetText("Use Docker")
	self.Settings.UseDockerText:SetPoint("TOPLEFT", self.Settings.UseDocker, "TOPRIGHT", 0, -1)
	
	
	self.Settings.TooltipAnchorText = UI.CreateFrame("Text", "Settings.TooltipAnchorText", self.um_Tab1)
	self.Settings.TooltipAnchorText:SetText("Tooltip Anchor (?)")
	self.Settings.TooltipAnchorText.HelpText = "Tooltip Anchor setting is used to determine where the tooltip will appear. TOOLTIP will cause the tooltip to attach to Rift's tooltip (default). TOPLEFT, TOPRIGHT, BOTTOMLEFT, or BOTTOMRIGHT will anchor the tooltip within the UpgradeMe's tooltip anchor window.  Unlock the UI to see the UpgradeMe tooltip anchor window."	
	self.Settings.TooltipAnchorText:EventAttach(Event.UI.Input.Mouse.Cursor.In, function(_self) self.Settings:DisplayTip(_self, true) end, "UpgradeMe.TooltipAnchorText.MouseIn")
	self.Settings.TooltipAnchorText:EventAttach(Event.UI.Input.Mouse.Cursor.Out, function() self.Settings:DisplayTip(false) end, "UpgradeMe.TooltipAnchorText.MouseOut")
	
	self.Settings.TooltipAnchorText:SetPoint("TOPLEFT", self.Settings.UseDocker, "BOTTOMLEFT", 0, 15)
	self.Settings.TooltipAnchor = UI.CreateFrame("SimpleSelect", "Settings.TooltipAnchor", self.um_Tab1)
	self.Settings.TooltipAnchor:SetWidth(150)
	self.Settings.TooltipAnchor:SetBorder(1, 0.5, 0.5, 0.5, 1)
	self.Settings.TooltipAnchor.Event.ItemSelect = function(item, value, index)
		umData.um_UI.TooltipAnchor = value
		UpgradeMe:SetUI()
	end
	self.Settings.TooltipAnchor:SetLayer(998)
	self.Settings.TooltipAnchor:SetPoint("TOPLEFT", self.Settings.TooltipAnchorText, "TOPRIGHT", 5, 0)	

	self.Settings.FrameAnchorText = UI.CreateFrame("Text", "Settings.FrameAnchorText", self.um_Tab1)
	self.Settings.FrameAnchorText:SetText("Outfit Popup Menu Position (?)")
	self.Settings.FrameAnchorText.HelpText = "Outfit Popup Menu Position will determine where the outfit popup menu will display in relation to the UpgradeMe menu button."
	self.Settings.FrameAnchorText:EventAttach(Event.UI.Input.Mouse.Cursor.In, function(_self) self.Settings:DisplayTip(_self, true) end, "UpgradeMe.FrameAnchorText.MouseIn")
	self.Settings.FrameAnchorText:EventAttach(Event.UI.Input.Mouse.Cursor.Out, function() self.Settings:DisplayTip(false) end, "UpgradeMe.FrameAnchorText.MouseOut")	
	self.Settings.FrameAnchorText:SetPoint("TOPLEFT", self.Settings.TooltipAnchorText, "BOTTOMLEFT", 0, 20)
	self.Settings.FrameAnchor = UI.CreateFrame("SimpleSelect", "Settings.FrameAnchor", self.um_Tab1)
	self.Settings.FrameAnchor:SetWidth(150)
	self.Settings.FrameAnchor:SetBorder(1, 0.5, 0.5, 0.5, 1)
	self.Settings.FrameAnchor.Event.ItemSelect = function(item, value, index)
		umData.um_UI.FrameAnchor = value
		UpgradeMe:SetUI()
	end	
	self.Settings.FrameAnchor:SetLayer(998)
	self.Settings.FrameAnchor:SetPoint("TOPLEFT", self.Settings.FrameAnchorText, "TOPRIGHT", 5, 0)
	
	self.Settings.DefaultItems = UI.CreateFrame("Text", "Settings.DefaultItems", self.um_Tab1)
	self.Settings.DefaultItems:SetText("Default Main Hand and Default Off Hand (?)")
	self.Settings.DefaultItems.HelpText = "Default main hand and off hand will be used to calculate upgrade value in the case where you want to compare a one handed/off hand drop to a two handed weapon.  UI must be unlocked to update default items.\n\n* MAIN HAND: To save a default main hand simply hold down your LEFT mouse button and then hover over desired item.\n\n* OFF HAND: To save a default off hand simply hold down your RIGHT mouse button and then hover over desired item.\n\nTo remove a default item, just double click the item to remove."
	self.Settings.DefaultItems:EventAttach(Event.UI.Input.Mouse.Cursor.In, function(_self) self.Settings:DisplayTip(_self, true) end, "UpgradeMe.DefaultItems.MouseIn")
	self.Settings.DefaultItems:EventAttach(Event.UI.Input.Mouse.Cursor.Out, function() self.Settings:DisplayTip(false) end, "UpgradeMe.DefaultItems.MouseOut")		
	self.Settings.DefaultItems:SetPoint("TOPLEFT", self.Settings.FrameAnchorText, "BOTTOMLEFT", 0, 20)
	
	self.Settings.OutfitHandMainFrame = UI.CreateFrame("Frame", "Settings.OutfitHandMainFrame", self.um_Tab1)
	self.Settings.OutfitHandMainFrame:SetBackgroundColor(0, 0, 0, 1)
	self.Settings.OutfitHandMainFrame:SetHeight(44)
	self.Settings.OutfitHandMainFrame:SetWidth(44)
	self.Settings.OutfitHandMainFrame:SetLayer(1)
	--self.Settings.OutfitHandMainFrame.HelpText = "Default main hand and off hand will be used to calculate upgrade value in the case where you want to\ncompare a one handed/off hand drop to a two handed weapon.  In order to save a default main hand or\na default off hand, simply hold down your right mouse button and then hover over desired item. To\nremove a default item, just double click the item to remove."
	---self.Settings.OutfitHandMainFrame:EventAttach(Event.UI.Input.Mouse.Cursor.In, function(_self) self.Settings:DisplayTip(_self, true) end, "UpgradeMe.OutfitHandMainFrame.MouseIn")
	--self.Settings.OutfitHandMainFrame:EventAttach(Event.UI.Input.Mouse.Cursor.Out, function() self.Settings:DisplayTip(false) end, "UpgradeMe.OutfitHandMainFrame.MouseOut")	
	self.Settings.OutfitHandMainFrame:SetPoint("TOPLEFT", self.Settings.DefaultItems, "BOTTOMLEFT", 0, 5)
	
	self.Settings.OutfitHandMain = UI.CreateFrame("Texture", "Settings.OutfitHandMain", self.um_Tab1)
	self.Settings.OutfitHandMain:SetHeight(40)
	self.Settings.OutfitHandMain:SetWidth(40)
	self.Settings.OutfitHandMain:SetLayer(2)
	self.Settings.OutfitHandMain.LastClick = -1
	self.Settings.OutfitHandMain:SetBackgroundColor(0, 0, 0, 1)
	--self.Settings.OutfitHandMain.HelpText = "Default main hand and off hand will be used to calculate upgrade value in the case where you want to\ncompare a one handed/off hand drop to a two handed weapon.  In order to save a default main hand or\na default off hand, simply hold down your right mouse button and then hover over desired item. To\nremove a default item, just double click the item to remove."		
	--self.Settings.OutfitHandMain:EventAttach(Event.UI.Input.Mouse.Cursor.In, function(_self) self.Settings:DisplayTip(_self, true) end, "UpgradeMe.OutfitHandMain.MouseIn")
	--self.Settings.OutfitHandMain:EventAttach(Event.UI.Input.Mouse.Cursor.Out, function() self.Settings:DisplayTip(false) end, "UpgradeMe.OutfitHandMain.MouseOut")		
	self.Settings.OutfitHandMain:SetPoint("TOPLEFT", self.Settings.OutfitHandMainFrame, "TOPLEFT", 2, 2)
	self.Settings.OutfitHandMain:EventAttach(Event.UI.Input.Mouse.Left.Click, function(_self) 
			local _now = Inspect.Time.Frame()
			if _self.LastClick > 0 and  _now - _self.LastClick < 1 then
				_self.LastClick = -1
				umData.um_UI.HandMainID = ""
				LoadOutfitDefaults(self)
			else
				_self.LastClick = _now
			end
		end, "UpgradeMe.Settings.HandMainDoubleClick")	
		
	self.Settings.OutfitHandMainText = UI.CreateFrame("Text", "Settings.OutfitHandMainText", self.um_Tab1)
	self.Settings.OutfitHandMainText:SetText("No Main Hand Saved")
	self.Settings.OutfitHandMainText:SetPoint("CENTERLEFT", self.Settings.OutfitHandMainFrame, "CENTERRIGHT", 5, 0)
	
	self.Settings.OutfitHandOffFrame = UI.CreateFrame("Frame", "Settings.OutfitHandOffFrame", self.um_Tab1)
	self.Settings.OutfitHandOffFrame:SetBackgroundColor(0, 0, 0, 1)
	self.Settings.OutfitHandOffFrame:SetHeight(44)
	self.Settings.OutfitHandOffFrame:SetWidth(44)	
	self.Settings.OutfitHandOffFrame:SetLayer(1)
	--self.Settings.OutfitHandOffFrame.HelpText = "Default main hand and off hand will be used to calculate upgrade value in the case where you want to\ncompare a one handed/off hand drop to a two handed weapon.  In order to save a default main hand or\na default off hand, simply hold down your right mouse button and then hover over desired item. To\nremove a default item, just double click the item to remove."
	--self.Settings.OutfitHandOffFrame:EventAttach(Event.UI.Input.Mouse.Cursor.In, function(_self) self.Settings:DisplayTip(_self, true) end, "UpgradeMe.OutfitHandOffFrame.MouseIn")
	--self.Settings.OutfitHandOffFrame:EventAttach(Event.UI.Input.Mouse.Cursor.Out, function() self.Settings:DisplayTip(false) end, "UpgradeMe.OutfitHandOffFrame.MouseOut")		
	self.Settings.OutfitHandOffFrame:SetPoint("TOPLEFT", self.Settings.OutfitHandMainFrame, "BOTTOMLEFT", 0, 5)
	
	self.Settings.OutfitHandOff = UI.CreateFrame("Texture", "Settings.OutfitHandOff", self.um_Tab1)
	self.Settings.OutfitHandOff:SetHeight(40)
	self.Settings.OutfitHandOff:SetWidth(40)
	self.Settings.OutfitHandOff:SetLayer(2)
	self.Settings.OutfitHandOff.LastClick = -1
	self.Settings.OutfitHandOff:SetBackgroundColor(0, 0, 0, 1)
	--self.Settings.OutfitHandOff.HelpText = "Default main hand and off hand will be used to calculate upgrade value in the case where you want to\ncompare a one handed/off hand drop to a two handed weapon.  In order to save a default main hand or\na default off hand, simply hold down your right mouse button and then hover over desired item. To\nremove a default item, just double click the item to remove."	
	--self.Settings.OutfitHandOff:EventAttach(Event.UI.Input.Mouse.Cursor.In, function(_self) self.Settings:DisplayTip(_self, true) end, "UpgradeMe.OutfitHandOff.MouseIn")
	--self.Settings.OutfitHandOff:EventAttach(Event.UI.Input.Mouse.Cursor.Out, function() self.Settings:DisplayTip(false) end, "UpgradeMe.OutfitHandOff.MouseOut")		
	self.Settings.OutfitHandOff:SetPoint("TOPLEFT", self.Settings.OutfitHandOffFrame, "TOPLEFT", 2, 2)
	self.Settings.OutfitHandOff:EventAttach(Event.UI.Input.Mouse.Left.Click, function(_self) 
			local _now = Inspect.Time.Frame()
			if _self.LastClick > 0 and  _now - _self.LastClick < 1 then
				_self.LastClick = -1
				umData.um_UI.HandOffID = ""
				LoadOutfitDefaults(self)
			else
				_self.LastClick = _now
			end
		end, "UpgradeMe.Settings.HandOffDoubleClick")		
		
	self.Settings.OutfitHandOffText = UI.CreateFrame("Text", "Settings.OutfitHandOffText", self.um_Tab1)
	self.Settings.OutfitHandOffText:SetText("No Off Hand Saved")
	self.Settings.OutfitHandOffText:SetPoint("CENTERLEFT", self.Settings.OutfitHandOff, "CENTERRIGHT", 5, 0)
	
	self.Settings.Help = UI.CreateFrame("Text", "Settings.Help", self.um_Tab1)
	self.Settings.Help:SetWordwrap(true)
	self.Settings.Help:SetText("Hover over option's (?) for more information.")
	self.Settings.Help:SetPoint("TOPLEFT", self.Settings.OutfitHandOff, "BOTTOMLEFT", 0, 30)
	self.Settings.Help:SetPoint("BOTTOMRIGHT", self.um_Tab1, "BOTTOMRIGHT", -10, -10)

	self.Settings.DisplayTip = function(_self, _option, _display)
		if _display then
			self.Settings.Help:SetText(_option.HelpText)
		else
			self.Settings.Help:SetText("Hover over option or (?) for more information.")
		end
	end
	
	-- self.Settings.SaveButton = UI.CreateFrame("Text", "Settings.SaveButton", self.um_Tab1)
	-- self.Settings.SaveButton:SetText("SAVE")
	-- self.Settings.SaveButton:SetBackgroundColor(1, 1, 1, .8)
	-- self.Settings.SaveButton:SetFontColor(0, 0, 0, 1)
	-- self.Settings.SaveButton:SetPoint("BOTTOMRIGHT", self.um_Tab1, "BOTTOMRIGHT", -10, -10)
	-- self.Settings.SaveButton:EventAttach(Event.UI.Input.Mouse.Left.Click, function(_self) UpgradeMe:SetUI() end, "UpgradeMe.SaveButtonClick")
	
	--self.ConfigInfo = UI.CreateFrame("Text", "configInfoText", self.um_Tab1)
	--self.ConfigInfo:SetFontSize(14)
	--self.ConfigInfo:SetWordwrap(true)
	--self.ConfigInfo:SetText(GetBuildInfo())
	--self.ConfigInfo:SetPoint("TOPLEFT", self.um_Tab1, "TOPLEFT", 10, 10)
	--self.ConfigInfo:SetPoint("BOTTOMRIGHT", self.um_Tab1, "BOTTOMRIGHT", -10, -10)
	--[[
	Info Config Set up Begin
	]]--

	--[[
	Weight Sets Config Set up Begin
	]]--
	self.OutfitsLbl = UI.CreateFrame("Text", "configOutfitsLbl", self.um_Tab2)
	self.OutfitsLbl:SetText("Saved Outfits: ")
	self.OutfitsLbl:SetPoint("TOPLEFT", self.um_Tab2, "TOPLEFT", 10, 10)

	self.Outfits = UI.CreateFrame("SimpleSelect", "configOutfits", self.um_Tab2)
	self.Outfits:SetWidth(285)
	self.Outfits.SetBorder(self.Outfits, 1, 0.5, 0.5, 0.5, 1)
	self.Outfits.Event.ItemSelect = self.OutfitSelected
	self.Outfits:SetLayer(999)
	self.Outfits:SetPoint("CENTERLEFT", self.OutfitsLbl, "CENTERRIGHT", 0, 0)

	self.NewOutfitLbl = UI.CreateFrame("Text", "configNewOutfitlbl", self.um_Tab2)
	self.NewOutfitLbl:SetText("Outfit Name: ")
	self.NewOutfitLbl:SetPoint("TOPLEFT", self.OutfitsLbl, "BOTTOMLEFT", 0, 5)

	self.NewOutfit = UI.CreateFrame("RiftTextfield", "configNewOutfit", self.um_Tab2)
	self.NewOutfit:SetBackgroundColor(0.4,0.4,0.4,1)
	Library.LibSimpleWidgets.SetBorder(self.NewOutfit, 1, 0.5, 0.5, 0.5, 1)
	self.NewOutfit:SetWidth(285)
	self.NewOutfit:SetPoint("CENTERLEFT", self.NewOutfitLbl, "CENTERRIGHT", 5, 0)

	self.NewOutfitDescLbl = UI.CreateFrame("Text", "configNewOutfitDesclbl", self.um_Tab2)
	self.NewOutfitDescLbl:SetText("Description: ")
	self.NewOutfitDescLbl:SetPoint("TOPLEFT", self.NewOutfitLbl, "BOTTOMLEFT", 0, 5)

	self.NewOutfitDescription = UI.CreateFrame("RiftTextfield", "configNewOutfitDesc", self.um_Tab2)
	self.NewOutfitDescription:SetBackgroundColor(0.4,0.4,0.4,1)
	Library.LibSimpleWidgets.SetBorder(self.NewOutfitDescription, 1, 0.5, 0.5, 0.5, 1)
	self.NewOutfitDescription:SetWidth(285)
	self.NewOutfitDescription:SetPoint("TOPLEFT", self.NewOutfit, "BOTTOMLEFT", 0, 5)

	self.SavedStatsLbl = UI.CreateFrame("Text", "configSavedStatslbl", self.um_Tab2)
	self.SavedStatsLbl:SetText("Stats Weights: ")
	self.SavedStatsLbl:SetPoint("TOPLEFT", self.NewOutfitDescLbl, "BOTTOMLEFT", 0, 5)

	self.SavedStats = UI.CreateFrame("SimpleSelect", "configSavedSets", self.um_Tab2)
	self.SavedStats:SetWidth(285)
	self.SavedStats.SetBorder(self.SavedStats, 1, 0.5, 0.5, 0.5, 1)
	self.SavedStats.Event.ItemSelect = self.StatSetSelected
	self.SavedStats:SetLayer(998)
	self.SavedStats:SetPoint("TOPLEFT", self.NewOutfitDescription, "BOTTOMLEFT", 0, 5)

	--Role
	self.RoleSlotLbl = UI.CreateFrame("Text", "conifgRoleSlotLbl", self.um_Tab2)
	self.RoleSlotLbl:SetText("Role: ")
	self.RoleSlotLbl:SetPoint("CENTERLEFT", self.NewOutfit, "CENTERRIGHT", 10, 0)
	
	self.RoleSlot = UI.CreateFrame("SimpleSelect", "configRoleSlot", self.um_Tab2)
	self.RoleSlot:SetWidth(100)
	self.RoleSlot.SetBorder(self.RoleSlot, 1, 0.5, 0.5, 0.5, 1)
	self.RoleSlot:SetLayer(997)
	self.RoleSlot:SetPoint("CENTERLEFT", self.NewOutfit, "CENTERRIGHT", 75, 0)
	
	--Equipment Set
	self.EquipSetLbl = UI.CreateFrame("Text", "conifgEquipSetLbl", self.um_Tab2)
	self.EquipSetLbl:SetText("Equip Set: ")
	self.EquipSetLbl:SetPoint("TOPLEFT", self.RoleSlotLbl, "BOTTOMLEFT", 0, 5)
	
	self.EquipSet = UI.CreateFrame("SimpleSelect", "configEquipSet", self.um_Tab2)
	self.EquipSet:SetWidth(100)
	self.EquipSet.SetBorder(self.EquipSet, 1, 0.5, 0.5, 0.5, 1)
	self.EquipSet:SetLayer(998)
	self.EquipSet:SetPoint("TOPLEFT", self.RoleSlot, "BOTTOMLEFT", 0, 5)
	
	-- Wardrobe
	self.WardrobeSetLbl = UI.CreateFrame("Text", "conifgWardrobeSetLbl", self.um_Tab2)
	self.WardrobeSetLbl:SetText("Wardrobe: ")
	self.WardrobeSetLbl:SetPoint("TOPLEFT", self.EquipSetLbl, "BOTTOMLEFT", 0, 5)
	
	self.WardrobeSet = UI.CreateFrame("SimpleSelect", "configWardrobeSet", self.um_Tab2)
	self.WardrobeSet:SetWidth(100)
	self.WardrobeSet.SetBorder(self.WardrobeSet, 1, 0.5, 0.5, 0.5, 1)
	self.WardrobeSet:SetLayer(999)
	self.WardrobeSet:SetPoint("TOPLEFT", self.EquipSet, "BOTTOMLEFT", 0, 5)
	
	pFld = self.SavedStatsLbl
	for statname, statrec in pairs(self.Datasets.GetStatsInOrder()) do
		_fld = statrec[3]
		self.StatNames[_fld..""] = UI.CreateFrame("Text", "conifg.statlbl".._fld, self.um_Tab2)
		self.StatNames[_fld..""]:SetText(statrec[2])
		self.StatNames[_fld..""]:SetWidth(60)
		self.StatNames[_fld..""]:SetHeight(20)

		self.StatWeights1[_fld..""] = umSlider("config.stattxt"..statrec[2], self.um_Tab2)
		self.StatWeights1[_fld..""]:SetWidth(150)
		self.StatWeights1[_fld..""]:SetRange(0, 10, .001)
		self.StatWeights1[_fld..""]:SetEditable(true)
		self.StatWeights1[_fld..""]:SetPosition(0)

		if iRow == 0 then
			self.StatNames[_fld..""]:SetPoint("TOPLEFT", pFld, "BOTTOMLEFT", iCol+25, 10)
		elseif iRow < 19 then
			self.StatNames[_fld..""]:SetPoint("TOPLEFT", self.StatNames[pFld..""], "BOTTOMLEFT", 0, 5)
		end
		self.StatWeights1[_fld..""]:SetPoint("TOPLEFT",self.StatNames[_fld..""], "TOPRIGHT", 25, 0)

		iRow = iRow + 1
		pFld = _fld
		if iRow == 18 then
			iRow = 0
			pFld = self.SavedStats
			iCol = 180
		end
	end

	self.StartNewOutfit = UI.CreateFrame("Text", "configCancelOutfit", self.um_Tab2)
	self.StartNewOutfit:SetBackgroundColor(0.7,0.7,0.7,1)
	self.StartNewOutfit:SetFontColor(0,0,0,1)
	Library.LibSimpleWidgets.SetBorder(self.StartNewOutfit, 1, 0.5, 0.5, 0.5, 1)
	self.StartNewOutfit:SetText("New Outfit")
	self.StartNewOutfit:EventAttach(Event.UI.Input.Mouse.Left.Click, function(_self, val) self:StartNewOutfitClick() end, "UMConfig.NewLeftClick")

	self.CreateOutfit = UI.CreateFrame("Text", "configCreateOutfit", self.um_Tab2)
	self.CreateOutfit:SetBackgroundColor(0.7,0.7,0.7,1)
	self.CreateOutfit:SetFontColor(0,0,0,1)
	Library.LibSimpleWidgets.SetBorder(self.CreateOutfit, 1, 0.5, 0.5, 0.5, 1)
	self.CreateOutfit:SetText("Save Outfit")
	self.CreateOutfit:EventAttach(Event.UI.Input.Mouse.Left.Click, 
		function(_self, val) 
			local gs = self.EquipSet:GetSelectedIndex()
			if not gs then gs = 1 end
			gs = tonumber(gs - 1)
			
			local rs = self.RoleSlot:GetSelectedIndex()
			if not rs then rs = 1 end
			rs = tonumber(rs - 1)
			
			local ws = self.WardrobeSet:GetSelectedIndex()
			if not ws then ws = 1 end
			ws = tonumber(ws - 1)
			
			self:CreateOutfitClick(self.NewOutfit:GetText(), self.NewOutfitDescription:GetText(), rs, gs, ws) 
		end, "UMConfig.CreateOutfitLeftClick")

	self.DeleteOutfit = UI.CreateFrame("Text", "configDeleteOutfit", self.um_Tab2)
	self.DeleteOutfit:SetBackgroundColor(0.7,0.7,0.7,1)
	self.DeleteOutfit:SetFontColor(0,0,0,1)
	Library.LibSimpleWidgets.SetBorder(self.DeleteOutfit, 1, 0.5, 0.5, 0.5, 1)
	self.DeleteOutfit:SetText("Delete Outfit")
	self.DeleteOutfit:EventAttach(Event.UI.Input.Mouse.Left.Click, function(_self, val) self:DeleteOutfitClick() end, "UMConfig.DeleteLeftClick")

	self.CancelOutfit = UI.CreateFrame("Text", "configCancelOutfit", self.um_Tab2)
	self.CancelOutfit:SetBackgroundColor(0.7,0.7,0.7,1)
	self.CancelOutfit:SetFontColor(0,0,0,1)
	Library.LibSimpleWidgets.SetBorder(self.CancelOutfit, 1, 0.5, 0.5, 0.5, 1)
	self.CancelOutfit:SetText("Cancel Changes")
	self.CancelOutfit:EventAttach(Event.UI.Input.Mouse.Left.Click, function(_self, val) self:CancelOutfitClick() end, "UMConfig.UMConfig.CancelLeftClick")

	self.StartNewOutfit:SetPoint("BOTTOMLEFT", self:GetContent(), "BOTTOMLEFT", 10, -10)
	self.CancelOutfit:SetPoint("BOTTOMCENTER", self:GetContent(), "BOTTOMCENTER", 40, -10)
	self.CreateOutfit:SetPoint("TOPRIGHT", self.CancelOutfit, "TOPLEFT", -10, 0)
	self.DeleteOutfit:SetPoint("BOTTOMRIGHT", self:GetContent(), "BOTTOMRIGHT", -10, -10)
	--[[
	Weight Sets Config Set up END
	]]--
end

local function LoadSettings(_self)
	_idx = nil
	_anchor = umData.um_UI.TooltipAnchor
	
	_self.Settings.TooltipAnchor:SetItems({"TOOLTIP", "TOPLEFT", "TOPRIGHT", "BOTTOMLEFT", "BOTTOMRIGHT"})
	if _anchor == "TOPLEFT" then _idx = 2 elseif _anchor == "TOPRIGHT" then _idx = 3 elseif _anchor == "BOTTOMLEFT" then _idx = 4 elseif _anchor == "BOTTOMRIGHT" then _idx = 5 else _idx = 1 end
	_self.Settings.TooltipAnchor:SetSelectedIndex(_idx, true)
	
	_idx = nil
	_anchor = umData.um_UI.FrameAnchor
	
	_self.Settings.FrameAnchor:SetItems({"TOPLEFT", "TOPRIGHT", "BOTTOMLEFT", "BOTTOMRIGHT"})	
	if _anchor == "TOPLEFT" then _idx = 1 elseif _anchor == "TOPRIGHT" then _idx = 2 elseif _anchor == "BOTTOMLEFT" then _idx = 3 elseif _anchor == "BOTTOMRIGHT" then _idx = 4 else _idx = 1 end
	_self.Settings.FrameAnchor:SetSelectedIndex(_idx, true)
	
	LoadOutfitDefaults(_self)
end

local function CancelOutfitClick(self)
	if self.Outfits:GetSelectedItem() then
		self:OutfitSelected(self.Outfits:GetSelectedItem(), nil, nil)
	else
		self:ClearConfigStats()
		self:ClearConfigInput()
	end
end

local function StartNewOutfitClick(self)
	self:ClearConfigStats()
	self:ClearConfigInput()
end

local function DeleteOutfitClick(self)
	_del = self.NewOutfit:GetText()
	if _del ~= "" and UpgradeMe.Outfits[_del] then
		UpgradeMe.Outfits[_del]["OutfitItems"] = nil
		UpgradeMe.Outfits[_del]["OutfitWeights"] = nil
		UpgradeMe.Outfits[_del] = nil
	end
	self:ClearConfigStats()
	self:ClearConfigInput()

	UpgradeMe.ValidateOutfit()
	UpgradeMe.GetCurrentOutfits()
end

local function CreateOutfitClick(self, _newoutfit, _description, _roleslot, _equipset, _wardrobeset)
	if not _newoutfit or _newoutfit == "" then
		print("You must enter outfit name and description to save.")
		return
	end

	local _temp = {}
	local _val = nil
	local _check = nil
	local _newstats = UpgradeMe.StatData.GetStatSet("blank", "blank")
	for stat, weight in pairs(_newstats) do
		_val = tonumber(self.StatWeights1[stat..""]:GetPosition())
		if _val and _val > 0 then
			_check = 1
			_temp[stat..""] = UpgradeMe.StatData.GetNewStatRecord()
			_temp[stat..""]["StatName"] = stat
			_temp[stat..""]["StatWeight1"] = self.StatWeights1[stat..""]:GetPosition()
		end
	end
    if not _check then
		print("You must set at least one stat > 0 to save.")
		return
	end

	local _slotname = ""
	UpgradeMe.Outfits[_newoutfit..""] = {["Name"]=_newoutfit, ["Description"]=_description, ["GearSet"]=_equipset, ["Role"]=_roleslot, ["Wardrobe"]=_wardrobeset, ["p2"]=nil, ["p3"]=nil, ["p4"]=nil, ["p5"]=nil, ["OutfitItems"]=UpgradeMe.OutfitData.NewEquipRecord(), ["OutfitWeights"]=nil}
	for slot, item in pairs(UpgradeMe.Outfits[_newoutfit..""]["OutfitItems"]) do
		if slot ~= "twohand" then _slotname = slot else _slotname = "handmain" end
		_idetail = UpgradeMe.GetItemDetail(Utility.Item.Slot.Equipment(_slotname))
		if _idetail then
			item["Slot"]= slot
			item["Name"]= _idetail.name
			item["ID"] = _idetail.id
		end
	end
	UpgradeMe.Outfits[_newoutfit..""]["OutfitWeights"] = _temp
	UpgradeMe.flgTooltip = false
	UpgradeMe.ValidateOutfit()
	UpgradeMe.GetCurrentOutfits()
	self:StartNewOutfitClick()
end

local function SaveOutfit(self, _outfit, _override)
	if not UpgradeMe.Outfits[_outfit] then
		print("Can't find outfit "..tostring(_outfit)..".  Please check your spelling or type /upme to find outfit.")
		return
	end

	UpgradeMe.Outfits[_outfit]["OutfitItems"] = nil
	UpgradeMe.Outfits[_outfit]["OutfitItems"] = UpgradeMe.OutfitData.NewEquipRecord()
	local _slotname = ""
	for slot, item in pairs(UpgradeMe.Outfits[_outfit]["OutfitItems"]) do
		if slot ~= "twohand" then _slotname = slot else _slotname = "handmain" end
		_idetail = UpgradeMe.GetItemDetail(Utility.Item.Slot.Equipment(_slotname))
		if _idetail then	
			item["Slot"] = slot
			item["Name"] = _idetail.name
			item["ID"] = _idetail.id
		else
			item["Slot"] = "DELETE"
		end
	end
	UpgradeMe.ValidateOutfit()
	if not _override then UpgradeMe.GetCurrentOutfits() end
	print("Outfit "..tostring(_outfit).." saved.")
end

local function OutfitSelected(item, value, index)
	self = UpgradeMe.Config
	self.SavedStats:SetSelectedIndex(-1, true)
	self:ClearConfigStats()

	local rs = UpgradeMe.Outfits[value]["Role"]
	if not rs then rs = 0 end
	rs = rs + 1
	
	local gs = UpgradeMe.Outfits[value]["GearSet"]
	if not gs then gs = 0 end
	gs = gs + 1
	
	local ws = UpgradeMe.Outfits[value]["Wardrobe"]
	if not ws then ws = 0 end
	ws = ws + 1
	
	self.NewOutfit:SetText(UpgradeMe.Outfits[value]["Name"])
	self.NewOutfitDescription:SetText(UpgradeMe.Outfits[value]["Description"])
	self.RoleSlot:SetSelectedIndex(rs)
	self.EquipSet:SetSelectedIndex(gs)
	self.WardrobeSet:SetSelectedIndex(ws)
	for stat, weight in pairs(UpgradeMe.Outfits[value]["OutfitWeights"]) do
		self.StatWeights1[stat]:SetPosition(tonumber(weight["StatWeight1"]))
	end
end

local function StatSetSelected(item, value, index)
	self = UpgradeMe.Config
	self:ClearConfigStats()
	for stat, weight in pairs(UpgradeMe.StatData.GetStatSet(UpgradeMe.Calling, value)) do
		self.StatWeights1[stat]:SetPosition(tonumber(weight["StatWeight1"]))
	end
end

local function ClearConfigInput(self)
	self.Outfits:SetItems(UpgradeMe.OutfitData.Outfits())
	self.SavedStats:SetItems(UpgradeMe.StatData.GetStatSets(UpgradeMe.Calling))
	self.SavedStats:SetSelectedIndex(-1, true)

	self.RoleSlot:SetItems(UpgradeMe.OutfitData.RoleSlot())	
	self.RoleSlot:SetSelectedIndex(-1, true)
	
	self.EquipSet:SetItems(UpgradeMe.OutfitData.EquipSet())	
	self.EquipSet:SetSelectedIndex(-1, true)

	self.WardrobeSet:SetItems(UpgradeMe.OutfitData.WardrobeSet())	
	self.WardrobeSet:SetSelectedIndex(-1, true)
	
	self.NewOutfit:SetText("")
	self.NewOutfitDescription:SetText("")
	--self.NewOutfit:SetKeyFocus(true)
end

local function ClearConfigStats(self)
	for i, fld in pairs(self.StatWeights1) do fld:SetPosition(0) end
end

local function Show(self, _tab)
	self:ClearConfigStats()
	self:ClearConfigInput()
	--self.NewOutfit:SetKeyFocus(true)
	self:LoadSettings()
	self:SetVisible(true)
	if _tab then self.um_TabView:SetActiveTab(_tab) end

end

local function Hide(self)
	self.NewOutfit:SetKeyFocus(true)
	self.NewOutfit:SetKeyFocus(false)
	self:SetVisible(false)
end

function GetConfig(_parent, _data)
	local _config = {}
	_config = UI.CreateFrame("SimpleWindow", "UpgradeMe", _parent)

	_config.Parent = _parent
	_config.Datasets = _data

	_config.BuildConfig = BuildConfig
	_config.LoadSettings = LoadSettings
	_config.LoadOutfitDefaults = LoadOutfitDefaults
	_config.CreateOutfitClick = CreateOutfitClick
	_config.SaveOutfit = SaveOutfit
	_config.CancelOutfitClick = CancelOutfitClick
	_config.DeleteOutfitClick = DeleteOutfitClick
	_config.StartNewOutfitClick = StartNewOutfitClick
	_config.OutfitSelected = OutfitSelected
	_config.StatSetSelected = StatSetSelected
	_config.ClearConfigStats = ClearConfigStats
	_config.ClearConfigInput = ClearConfigInput
	_config.Hide = Hide
	_config.Show = Show
	
	Library.LibSimpleWidgets.EventProxy(_config, {"Close"})

	_config:BuildConfig()
	return _config
end
