local addoninfo, umData = ...
local addon = addoninfo.identifier

local function CreateOutfitFrame(_ui, _parent)
	_ui.OutfitFrame = UI.CreateFrame("Frame", "UM.OutfitFrame", _parent)
	_ui.OutfitFrame:SetSecureMode("restricted")
	_ui.OutfitFrame:SetBackgroundColor(0, 0, 0, 1)
	_ui.OutfitFrame:SetVisible(false)
	_ui.OutfitFrame:SetPoint(umData.um_UI.FrameAnchor, _ui.Icon, "CENTER", 0, 0)
	_ui.OutfitFrame:SetLayer(1)
	_ui.OutfitFrame.Outfits = {}
	_ui.OutfitFrame.ShowFrame = function(_self)
		if Inspect.System.Secure() then return end
		local m = Inspect.Mouse()
		
		UpgradeMe.ofContext:SetStrata("topmost")
		if (m["x"] < _self:GetLeft() or m["x"] > _self:GetRight() or m["y"] > _self:GetBottom() or m["y"] < _self:GetTop()) and not _ui.Icon.MouseIn then
			_self:SetVisible(false)
		else
			if  _self:GetVisible() then
				if UpgradeMe.SelectedOutfit then UpgradeMe.SelectedOutfit:SetBackgroundColor(0, 1, 0, .3) end
			end
			_self:SetVisible(true)
		end
	end	
	_ui.OutfitFrame.HideFrame = function (_self)
		_self:SetVisible(false)
	end
	_ui.OutfitFrame.SelectOutfit = 
		function(_self, _owidget) 
			if UpgradeMe.SelectedOutfit then UpgradeMe.SelectedOutfit:SetBackgroundColor(0, 0, 0, 1) end
			UpgradeMe.SelectedOutfit = _owidget
			if not _owidget then return end
			UpgradeMe.SelectedOutfit:SetBackgroundColor(0, 1, 0, .3)
		end
end

local function CreateTipAnchorFrame(_ui, _parent)
	_ui.TipAnchorFrame = UI.CreateFrame("Frame", "UM.TipAnchorFrame", _parent)
	_ui.TipAnchorFrame:SetWidth(250)
	_ui.TipAnchorFrame:SetHeight(100)
	_ui.TipAnchorFrame:SetBackgroundColor(0, 0, 0, .5)
	_ui.TipAnchorFrame:SetVisible(false)
	_ui.TipAnchorFrame:SetPoint("TOPLEFT", UIParent, "TOPLEFT", umData.um_UI.TipX, umData.um_UI.TipY)
	_ui.TipAnchorFrame.AnchorMouseMove = function(_self, xPos, yPos)
		if umData.um_UI.Locked or Inspect.System.Secure() then return end
		local mouse = Inspect.Mouse()
		if mouse.Right and not Inspect.System.Secure() then 
				_self:SetPoint("TOPLEFT", UIParent, "TOPLEFT", xPos - (_self:GetWidth()/2), yPos - (_self:GetHeight()/2)) 
				umData.um_UI.TipX = xPos - (_self:GetWidth()/2)
				umData.um_UI.TipY = yPos - (_self:GetHeight()/2)
		end
	end
	_ui.TipAnchorFrame.SetAnchorPoint = function(_self)
		local _pt = umData.um_UI.TooltipAnchor
		local _ap = _ui.TipAnchorPoint
		if _pt and _pt ~= "TOOLTIP" then	
			_ap:ClearAll()
			_ap:SetWidth(10)
			_ap:SetHeight(10)
			_ap:SetVisible(true)
			_ap:SetPoint(_pt, _self, _pt, 0, 0) 
		else 
			_ap:SetVisible(false)
		end
	end	
	_ui.TipAnchorFrame:EventAttach(Event.UI.Input.Mouse.Cursor.Move, function(_self, val, x, y) _self:AnchorMouseMove(x, y) end, addon..".AnchorMouseMove")

	_ui.TipAnchorFrameText = UI.CreateFrame("Text", "UM.TipAnchorFrameText", _ui.TipAnchorFrame)
	_ui.TipAnchorFrameText:SetText("         UpgradeMe Tooltip Anchor\n\nUse Right + Left Button Click And Drag")
	_ui.TipAnchorFrameText:SetPoint("CENTER", _ui.TipAnchorFrame, "CENTER")
	
	_ui.TipAnchorPoint = UI.CreateFrame("Frame", "UM.TipAnchorFrame", _ui.TipAnchorFrame)
	_ui.TipAnchorPoint:SetBackgroundColor(1, 0, 0, .5)
end

local function CreateMiniMapButton(_ui, _parent)
	_ui.Icon = UI.CreateFrame("Texture", "UM.UIButton", _parent)
	_ui.Icon.DefaultSize = 24	
	_ui.Icon.LastClick = -1
	_ui.Icon.MouseIn = false
	_ui.Icon:SetTexture("UpgradeMe", "Textures/upme.png")
	
	_ui.Icon:EventAttach(Event.UI.Input.Mouse.Cursor.In, 
		function(_self, val)
			_self:Show()
		end, addon..".IconMouseIn")
	_ui.Icon:EventAttach(Event.UI.Input.Mouse.Cursor.Out, 
		function(_self, val) 
			_self:Hide()
		end, addon..".IconMouseOut")	
	_ui.Icon:EventAttach(Event.UI.Input.Mouse.Left.Click, function(_self) 
		local _now = Inspect.Time.Frame()
		if _self.LastClick > 0 and  _now - _self.LastClick < 1 then
			_self.LastClick = -1
			if UpgradeMe.Config:GetVisible() then UpgradeMe.Config:Hide() else UpgradeMe.Config:Show(2) end
		else
			_self.LastClick = _now
		end
	end, addon..".UIDoubleClick")
		
	if not MINIMAPDOCKER or not umData.um_UI.UseDocker then
		_ui.Icon:SetWidth(_ui.Icon.DefaultSize * umData.um_UI.Scale)
		_ui.Icon:SetHeight(_ui.Icon.DefaultSize * umData.um_UI.Scale)	
		_ui.Icon:SetPoint("TOPLEFT", UIParent, "TOPLEFT", umData.um_UI.X, umData.um_UI.Y)
		_ui.Icon:SetLayer(2)

		_ui.Icon.Scale = function(_self, _step)
			if umData.um_UI.Locked or Inspect.System.Secure() then return end
			local _newScale = umData.um_UI.Scale + (_step)
			if _newScale < .69 or _newScale > 2.01 then return end
			
			_self:SetWidth(_ui.Icon.DefaultSize * _newScale)
			_self:SetHeight(_ui.Icon.DefaultSize * _newScale)
			
			umData.um_UI.Scale = _newScale
		end		
		_ui.Icon.UIMouseMove = function(_self, xPos, yPos)
			if umData.um_UI.Locked or Inspect.System.Secure() then return end
			local mouse = Inspect.Mouse()
			if mouse.Right and not Inspect.System.Secure() then 
					_self:SetPoint("TOPLEFT", UIParent, "TOPLEFT", xPos - (_self:GetWidth()/2), yPos - (_self:GetHeight()/2)) 
					umData.um_UI.X = xPos - (_self:GetWidth()/2)
					umData.um_UI.Y = yPos - (_self:GetHeight()/2)
			end
		end	
		_ui.Icon:EventAttach(Event.UI.Input.Mouse.Cursor.Move, function(_self, val, x, y) _self:UIMouseMove(x, y) end, addon..".UIMouseMove")
		_ui.Icon:EventAttach(Event.UI.Input.Mouse.Wheel.Back, function(_self, val) _self:Scale(-0.05) end, addon..".UIScaleDown")
		_ui.Icon:EventAttach(Event.UI.Input.Mouse.Wheel.Forward, function(_self, val) _self:Scale(.05) end, addon..".UIScaleUp")		
	else
		MINIMAPDOCKER.Register(addon, _ui.Icon, ClosePopup)
	end	
end

function InitUMUI(_parent)
	local _ui = {}
	
	CreateMiniMapButton(_ui, _parent)
	CreateOutfitFrame(_ui, _parent)
	CreateTipAnchorFrame(_ui, _parent)
	_ui.ClosePopup = function(_self)
		_self.Icon.MouseIn = false
		_self.OutfitFrame:HideFrame()
		if MINIMAPDOCKER and umData.um_UI.UseDocker then
			MINIMAPDOCKER.AUTOHIDE_DOCKED = true
		end
	end	
	_ui.Icon.Show = function()
		_ui.Icon.MouseIn = true
		if Inspect.System.Secure() == true then return end
		
		if MINIMAPDOCKER and umData.um_UI.UseDocker then
			MINIMAPDOCKER.AUTOHIDE_DOCKED = false
		end
		_ui.OutfitFrame:ShowFrame()
	end
	_ui.Icon.Hide = function()
		_ui.Icon.MouseIn = false
		_ui.OutfitFrame:ShowFrame()
		if MINIMAPDOCKER and umData.um_UI.UseDocker then
			MINIMAPDOCKER.AUTOHIDE_DOCKED = true
		end
	end	
	
	return _ui
end